==> jc-1.4.0.tar.gz: javax/swing/JSlider__24AccessibleJSlider.h <==
// public class javax.swing.JSlider$AccessibleJSlider

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 81faa19969765fab javax_swing_JSlider__24AccessibleJSlider

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JSlider__24AccessibleJSlider_H_
#define _JC_javax_swing_JSlider__24AccessibleJSlider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_accessibility_AccessibleValue$object;
struct _jc_javax_swing_JSlider$object;

// Typedefs
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs	_jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs	_jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$refs	_jc_javax_swing_JSlider__24AccessibleJSlider$refs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs	_jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$object	_jc_javax_swing_JSlider__24AccessibleJSlider$object;

typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct	_jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct;
typedef const struct _jc_javax_swing_JSlider__24AccessibleJSlider$vmethods	_jc_javax_swing_JSlider__24AccessibleJSlider$vmethods;
typedef const struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtable	_jc_javax_swing_JSlider__24AccessibleJSlider$vtable;
typedef const struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtype	_jc_javax_swing_JSlider__24AccessibleJSlider$vtype;

// Class fields structure
struct _jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct _jc_javax_swing_JSlider__24AccessibleJSlider$class_fields;

// Constructors
extern void _jc_javax_swing_JSlider__24AccessibleJSlider$method$_init$6fe6487678b9df2b(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *, struct _jc_javax_swing_JSlider$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
extern struct _jc_object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
extern jboolean _jc_javax_swing_JSlider__24AccessibleJSlider$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *, struct _jc_java_lang_Number$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getAccessibleStateSet$1a4e9ea496bda550;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_javax_swing_JSlider__24AccessibleJSlider$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *);
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *, struct _jc_java_lang_Number$object *);
};

// Vtable
struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JSlider__24AccessibleJSlider$vmethods	javax_swing_JSlider__24AccessibleJSlider;
};

// Vtype
struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtype {
	_jc_type			type;
	_jc_javax_swing_JSlider__24AccessibleJSlider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs {
	struct _jc_javax_swing_JSlider$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$refs {
    _jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs	javax_swing_JSlider__24AccessibleJSlider;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs	javax_swing_JSlider__24AccessibleJSlider;
};

// Object instance structure
struct _jc_javax_swing_JSlider__24AccessibleJSlider$object {
	_jc_javax_swing_JSlider__24AccessibleJSlider$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JSlider__24AccessibleJSlider$vtype	*vtype;
	_jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JSlider__24AccessibleJSlider$vtype _jc_javax_swing_JSlider__24AccessibleJSlider$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JSlider__24AccessibleJSlider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JSlider__24AccessibleJSlider$class_object;

#endif	/* _JC_javax_swing_JSlider__24AccessibleJSlider_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JSlider__24AccessibleJSlider.h <==
// public class javax.swing.JSlider$AccessibleJSlider

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 81faa19969765fab javax_swing_JSlider__24AccessibleJSlider

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JSlider__24AccessibleJSlider_H_
#define _JC_javax_swing_JSlider__24AccessibleJSlider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_accessibility_AccessibleValue$object;
struct _jc_javax_swing_JSlider$object;

// Typedefs
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs	_jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs	_jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$refs	_jc_javax_swing_JSlider__24AccessibleJSlider$refs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs	_jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs;
typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$object	_jc_javax_swing_JSlider__24AccessibleJSlider$object;

typedef struct _jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct	_jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct;
typedef const struct _jc_javax_swing_JSlider__24AccessibleJSlider$vmethods	_jc_javax_swing_JSlider__24AccessibleJSlider$vmethods;
typedef const struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtable	_jc_javax_swing_JSlider__24AccessibleJSlider$vtable;
typedef const struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtype	_jc_javax_swing_JSlider__24AccessibleJSlider$vtype;

// Class fields structure
struct _jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JSlider__24AccessibleJSlider$fields_struct _jc_javax_swing_JSlider__24AccessibleJSlider$class_fields;

// Constructors
extern void _jc_javax_swing_JSlider__24AccessibleJSlider$method$_init$6fe6487678b9df2b(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *, struct _jc_javax_swing_JSlider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JSlider__24AccessibleJSlider$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_JSlider__24AccessibleJSlider$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getAccessibleStateSet$1a4e9ea496bda550;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_javax_swing_JSlider__24AccessibleJSlider$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_javax_swing_JSlider__24AccessibleJSlider$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *) _JC_JCNI_ATTR;
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_javax_swing_JSlider__24AccessibleJSlider$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JSlider__24AccessibleJSlider$vmethods	javax_swing_JSlider__24AccessibleJSlider;
};

// Vtype
struct _jc_javax_swing_JSlider__24AccessibleJSlider$vtype {
	_jc_type			type;
	_jc_javax_swing_JSlider__24AccessibleJSlider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs {
	struct _jc_javax_swing_JSlider$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$refs {
    _jc_javax_swing_JSlider__24AccessibleJSlider$sub_refs	javax_swing_JSlider__24AccessibleJSlider;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JSlider__24AccessibleJSlider$sub_nonrefs	javax_swing_JSlider__24AccessibleJSlider;
};

// Object instance structure
struct _jc_javax_swing_JSlider__24AccessibleJSlider$object {
	_jc_javax_swing_JSlider__24AccessibleJSlider$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JSlider__24AccessibleJSlider$vtype	*vtype;
	_jc_javax_swing_JSlider__24AccessibleJSlider$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JSlider__24AccessibleJSlider$vtype _jc_javax_swing_JSlider__24AccessibleJSlider$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JSlider__24AccessibleJSlider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JSlider__24AccessibleJSlider$class_object;

#endif	/* _JC_javax_swing_JSlider__24AccessibleJSlider_H_ */
